==> oddmuse-1.684.tar.gz: oddmuse-1.684/spanish-utf8.pl <==
# UTF-8 encoded Spanish language file for use with Oddmuse
#
# Copyright (c) 2003  Unknown
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
$ModulesDescription .= '<p>$Id: spanish-utf8.pl,v 1.8 2006/05/10 22:52:16 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Consulta no permitida: el usuario, ip o sub-red ha sido bloqueado.
Could not create %s
No ha sido posible crear %s
Invalid UserName %s: not saved.
UserName %s inválido: no ha sido guardado.
UserName must be 50 characters or less: not saved
UserName debe tener un tamaño de 50 caracteres o menos: no ha sido guardado.
This page contains an uploaded file:

Recursive include of %s!

XML::RSS is not available on this system.

diff

history
historial
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

image

download

CGI Internal error: %s

Invalid action parameter %s
Parámetro de acción %s inválido
Invalid URL.
URL inválida.
Page name is missing

Page name is too long: %s
El nombre de la página es demasiado largo: %s
Invalid Page %s (must not end with .db)
Página %s Inválida (no debe terminar con la extensión .db)
Invalid Page %s (must not end with .lck)
Página %s Inválida (no debe terminar con la extensión .lck)
Invalid Page %s
Página %s Inválida
Preview:
Previsualización:
Preview only, not yet saved
Esta es únicamente una vista previa; no ha sido guardada aun.
Please go on to %s.
Por favor proceda a %s.
Could not open %s log file
No ha sido posible abrir el archivo de registro %s
Error was
El error fue
Note: This error is normal if no changes have been made.
Nota: Este error es normal si no se han efectuado modificaciones.
Could not open old %s log file
No ha sido posible abrir el archivo antiguo de registro %s
No updates since %s
No han habido actualizaciones desde %s
Updates since %s
Actualizaciones desde %s
Updates in the last %s days
Actualizaciones en los últimos %s días
Updates in the last %s day
Actualizaciones en el último %s día
for %s only
solo para %s
List latest change per page only

List all changes

List only major changes

Include minor changes

%s days
%s días
List later changes

Filters

Title:

Title and Body:

Username:

Host:

Language:

Go!
Iniciar
(minor)
(menor)
rollback

new

from %s
desde %s
This page is too big to send over RSS.

History of %s
Historial de %s
Compare
Comparar
Revision %s
Revisión %s
by
por
Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages
Índice de todas las páginas
Wiki Version
Versión del Wiki
Unlock Wiki
Deshabilitando el bloqueo
Password
Contraseña
Run maintenance

Unlock site

Lock site

Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Inicio]
redirected from %s
redireccionado desde %s
Click to search for references to this page

Cookie: 

Warning
Advertencia
Database is stored in temporary directory %s
La base de datos se encuentra almacenada temporalmente en el directorio %s
%s seconds
%s segundos
The same page on other sites:

EditNearLinks

Last edited
Editado por última vez
Edited
Editado
by %s

(diff)

Edit revision %s of this page
Editar la revisión %s de esta página
Edit this page
Editar el contenido de esta página
e

This page is read-only
Esta página se encuentra en modo de sólo-lectura
View other revisions
Ver otras revisiones
View current revision
Ver revisión actual
View all changes

Homepage URL:

s

Save
Guardar
p

Preview
Previsualización
Search:
Buscar:
f

Replace:
Reemplazar:
Validate HTML
Validar HTML
Validate CSS
Validar CSS
Difference (from revision %1 to %2)

revision %s
revisión %s
current revision
revisión actual
Difference (from prior %s revision)
Diferencias (previas a la revisión %s)
major
mayor
minor
menor
No diff available.
No hoy diffs disponibles.
The two revisions are the same.

Old revision:

Changed:
Modificado:
Removed:
Eliminado:
Added:
Agregado:
to
a
Revision %s not available
La revisión %s no está disponible.
showing current revision instead
se presenta en su lugar la revisión actual
Showing revision %s
La presente es la revisión %s
Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

The lock was created %s.

This operation may take several seconds...
Esta operación puede tomar varios segundos...
Forced unlock of %s lock.
Se ha forzado la desactivación del bloqueo %s.
No unlock required.
No se requiere una operación de desbloqueo.
%s hours ago
hace %s horas
1 hour ago
hace 1 hora
%s minutes ago
hace %s minutos
1 minute ago
hace 1 minuto
%s seconds ago
hace %s segundos
1 second ago
hace un segundo
just now
hace un instante
Edit Denied

Editing not allowed: user, ip, or network is blocked.
La edición no se es permitida: el usuario, ip o sub-red ha sido bloqueado.
Contact the wiki administrator for more information.
Contacte al administrador del wiki para más información.
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
La edición no se es permitida: %s es de sólo-lectura.
Only administrators can upload files.

Editing revision %s of
Editando la revisión %s de
Editing %s
Editando %s
Editing old revision %s.
Editando la revisión antigua %s.
Saving this page will replace the latest revision with this text.
Al ser guardada esta página, el contenido de la última revisión será reemplazado.
Summary:
Resumen:
This change is a minor edit.
Este cambio es solo una edición menor.
Replace this file with text.

Replace this text with a file.

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Su contraseña es almacenada en una cookie, si su navegador tiene habilitado su uso. Estas cookies pueden perderse si se conecta desde otra máquina, otra cuenta, o usando un software de navegación diferente.
You are currently an administrator on this site.
Actualmente usted es un administrador en este sitio.
You are currently an editor on this site.
Actualmente usted es un editor en este sitio.
You are a normal user on this site.
Usted es un usuario normal en este sitio.
Your password does not match any of the  administrator or editor passwords.
Su contraseña no coincide con ninguna de las contraseñas de administrador o editor.
Password:
Contraseña:
This site does not use admin or editor passwords.
Este sitio no utiliza contraseñas de administrador o editor.
This operation is restricted to site editors only...
Esta operación está restringida para su uso por editores únicamente...
This operation is restricted to administrators only...
Esta operación está restringida para su uso por administradores únicamente...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)

Filter:

%s pages found.

Replaced: %s
Reemplazado: %s
Search for: %s
Buscar por: %s
View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated
actualizado por última vez
Complete Content
Contenido Completo
The main page is %s.
La página principal es %s.
Comments on this page
Comentarios de esta página
Editing not allowed for %s.
No se permite la edición para %s.
SampleUndefinedPage
PaginaEjemploSinDefinir
%s cannot be defined.
%s no puede ser definida.
Sample_Undefined_Page
Pagina_Ejemplo_Sin_Definir
[[%s]] cannot be defined.
[[%s]] no puede ser definida.
Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous
Anónimo
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
¡No pudo obtenerse un bloqueo para incorporar los cambios!
you

ancestor

other

Run Maintenance

Maintenance not done.
El mantenimiento no se ha realizado.
(Maintenance can only be done once every 12 hours.)
(El mantenimiento solo puede realizarse cada 12 horas.)
Remove the "maintain" file or wait.
Elimine el archivo "maintain" o espere.
Main lock obtained.
Se obtuvo el bloqueo principal.
Expiring keep files and deleting pages marked for deletion
Expirando los archivos "keep" y eliminando las páginas marcadas para borrado
not deleted: 

deleted
eliminado
Moving part of the %s log file.
Moviendo parte del archivo de registro %s.
Moving %s log entries.
Moviendo %s entradas del registro.
Getting page index file for %s.

Main lock released.
Se ha liberado el bloqueo principal.
Set or Remove global edit lock
Establecer o Remover el bloqueo global de edición
Edit lock created.
Se ha creado un bloqueo de edición.
Edit lock removed.
Se ha eliminado el bloqueo de edición.
Set or Remove page edit lock
Establecer o Remover el bloqueo de edición de una página
Lock for %s created.
Se ha creado bloqueo para %s.
Lock for %s removed.
Se ha eliminado bloqueo para %s.
Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
Demasiadas conexiones de %s
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Learn more...

Cannot highlight the language %s.

Recent Visitors
Visitantes Recientes
some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Add Comment

ordinary changes

Footnotes:

Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:

Show!

Define

Full Link List
Lista Completa de Enlaces
Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

%s is not a legal name for a namespace

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 

None

Type

Permalink to "%s"

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Portrait

You did not answer correctly.

All Referrers
Todos los orígenes
Referrers
Orígenes
Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.

Result pages: 

(%s results)

Slideshow:%s

Static Copy

Back to %s

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
alternativo
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
buscar
Upload of %s file

Blog

Matching pages:

New

Edit %s.

END_OF_TRANSLATION

==> oddmuse-1.754.tar.gz: oddmuse-1.754/spanish-utf8.pl <==
# UTF-8 encoded Spanish language file for use with Oddmuse
#
# Copyright (c) 2003  Unknown
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
$ModulesDescription .= '<p>$Id: spanish-utf8.pl,v 1.9 2006/08/18 22:46:10 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Consulta no permitida: el usuario, ip o sub-red ha sido bloqueado.
%s calls

Could not create %s
No ha sido posible crear %s
Invalid UserName %s: not saved.
UserName %s inválido: no ha sido guardado.
UserName must be 50 characters or less: not saved
UserName debe tener un tamaño de 50 caracteres o menos: no ha sido guardado.
This page contains an uploaded file:

Recursive include of %s!

Clear Cache

Main lock obtained.
Se obtuvo el bloqueo principal.
Main lock released.
Se ha liberado el bloqueo principal.
Comments on this page
Comentarios de esta página
XML::RSS is not available on this system.

diff

history
historial
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

image

download

CGI Internal error: %s

Invalid action parameter %s
Parámetro de acción %s inválido
Invalid URL.
URL inválida.
Page name is missing

Page name is too long: %s
El nombre de la página es demasiado largo: %s
Invalid Page %s (must not end with .db)
Página %s Inválida (no debe terminar con la extensión .db)
Invalid Page %s (must not end with .lck)
Página %s Inválida (no debe terminar con la extensión .lck)
Invalid Page %s
Página %s Inválida
Preview:
Previsualización:
Preview only, not yet saved
Esta es únicamente una vista previa; no ha sido guardada aun.
Please go on to %s.
Por favor proceda a %s.
No updates since %s
No han habido actualizaciones desde %s
Updates since %s
Actualizaciones desde %s
Updates in the last %s days
Actualizaciones en los últimos %s días
Updates in the last %s day
Actualizaciones en el último %s día
for %s only
solo para %s
List latest change per page only

List all changes

Skip rollbacks

Include rollbacks

List only major changes

Include minor changes

%s days
%s días
List later changes

Filters

Title:

Title and Body:

Username:

Host:

Language:

Go!
Iniciar
(minor)
(menor)
rollback

new

from %s
desde %s
This page is too big to send over RSS.

History of %s
Historial de %s
Compare
Comparar
Deleted

Mark this page for deletion

No other revisions available

current

Revision %s
Revisión %s
Contributors to %s

Missing target for rollback.

Target for rollback is too far back.

Rolling back changes

The two revisions are the same.

Editing not allowed for %s.
No se permite la edición para %s.
Rollback to %s

%s rolled back

to %s

Index of all pages
Índice de todas las páginas
Wiki Version
Versión del Wiki
Unlock Wiki
Deshabilitando el bloqueo
Password
Contraseña
Run maintenance

Unlock site

Lock site

Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Inicio]
redirected from %s
redireccionado desde %s
Click to search for references to this page

Cookie: 

Warning
Advertencia
Database is stored in temporary directory %s
La base de datos se encuentra almacenada temporalmente en el directorio %s
%s seconds
%s segundos
The same page on other sites:

EditNearLinks

Last edited
Editado por última vez
Edited
Editado
by %s

(diff)

Edit revision %s of this page
Editar la revisión %s de esta página
Edit this page
Editar el contenido de esta página
e

This page is read-only
Esta página se encuentra en modo de sólo-lectura
View other revisions
Ver otras revisiones
View current revision
Ver revisión actual
View all changes

View contributors

Homepage URL:

s

Save
Guardar
p

Preview
Previsualización
Search:
Buscar:
f

Replace:
Reemplazar:
Validate HTML
Validar HTML
Validate CSS
Validar CSS
Last edit

Difference between revision %1 and %2

revision %s
revisión %s
current revision
revisión actual
Last major edit (%s)

later minor edits

No diff available.
No hoy diffs disponibles.
Old revision:

Changed:
Modificado:
Deleted:

Added:
Agregado:
to
a
Revision %s not available
La revisión %s no está disponible.
showing current revision instead
se presenta en su lugar la revisión actual
Showing revision %s
La presente es la revisión %s
Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

The lock was created %s.

This operation may take several seconds...
Esta operación puede tomar varios segundos...
Forced unlock of %s lock.
Se ha forzado la desactivación del bloqueo %s.
No unlock required.
No se requiere una operación de desbloqueo.
%s hours ago
hace %s horas
1 hour ago
hace 1 hora
%s minutes ago
hace %s minutos
1 minute ago
hace 1 minuto
%s seconds ago
hace %s segundos
1 second ago
hace un segundo
just now
hace un instante
Edit Denied

Editing not allowed: user, ip, or network is blocked.
La edición no se es permitida: el usuario, ip o sub-red ha sido bloqueado.
Contact the wiki administrator for more information.
Contacte al administrador del wiki para más información.
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
La edición no se es permitida: %s es de sólo-lectura.
Only administrators can upload files.

Editing revision %s of
Editando la revisión %s de
Editing %s
Editando %s
Editing old revision %s.
Editando la revisión antigua %s.
Saving this page will replace the latest revision with this text.
Al ser guardada esta página, el contenido de la última revisión será reemplazado.
Summary:
Resumen:
This change is a minor edit.
Este cambio es solo una edición menor.
Replace this file with text

Replace this text with a file

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Su contraseña es almacenada en una cookie, si su navegador tiene habilitado su uso. Estas cookies pueden perderse si se conecta desde otra máquina, otra cuenta, o usando un software de navegación diferente.
You are currently an administrator on this site.
Actualmente usted es un administrador en este sitio.
You are currently an editor on this site.
Actualmente usted es un editor en este sitio.
You are a normal user on this site.
Usted es un usuario normal en este sitio.
Your password does not match any of the  administrator or editor passwords.
Su contraseña no coincide con ninguna de las contraseñas de administrador o editor.
Password:
Contraseña:
This site does not use admin or editor passwords.
Este sitio no utiliza contraseñas de administrador o editor.
This operation is restricted to site editors only...
Esta operación está restringida para su uso por editores únicamente...
This operation is restricted to administrators only...
Esta operación está restringida para su uso por administradores únicamente...
SampleUndefinedPage
PaginaEjemploSinDefinir
Sample_Undefined_Page
Pagina_Ejemplo_Sin_Definir
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)

Filter:

%s pages found.

Replaced: %s
Reemplazado: %s
Search for: %s
Buscar por: %s
View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated
actualizado por última vez
by
por
Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous
Anónimo
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
¡No pudo obtenerse un bloqueo para incorporar los cambios!
you

ancestor

other

Run Maintenance

Maintenance not done.
El mantenimiento no se ha realizado.
(Maintenance can only be done once every 12 hours.)
(El mantenimiento solo puede realizarse cada 12 horas.)
Remove the "maintain" file or wait.
Elimine el archivo "maintain" o espere.
Expiring keep files and deleting pages marked for deletion
Expirando los archivos "keep" y eliminando las páginas marcadas para borrado
not deleted: 

deleted
eliminado
Moving part of the %s log file.
Moviendo parte del archivo de registro %s.
Could not open %s log file
No ha sido posible abrir el archivo de registro %s
Error was
El error fue
Note: This error is normal if no changes have been made.
Nota: Este error es normal si no se han efectuado modificaciones.
Moving %s log entries.
Moviendo %s entradas del registro.
Getting page index file for %s.

Set or Remove global edit lock
Establecer o Remover el bloqueo global de edición
Edit lock created.
Se ha creado un bloqueo de edición.
Edit lock removed.
Se ha eliminado el bloqueo de edición.
Set or Remove page edit lock
Establecer o Remover el bloqueo de edición de una página
Lock for %s created.
Se ha creado bloqueo para %s.
Lock for %s removed.
Se ha eliminado bloqueo para %s.
Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
Demasiadas conexiones de %s
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Learn more...

Complete Content
Contenido Completo
The main page is %s.
La página principal es %s.
Cannot highlight the language %s.

Recent Visitors
Visitantes Recientes
some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Add Comment

ordinary changes

Footnotes:

Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:

Show!

Define

Full Link List
Lista Completa de Enlaces
Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

%s is not a legal name for a namespace

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 

None

Type

Permalink to "%s"

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Portrait

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.

To save this page you must answer this question:

All Referrers
Todos los orígenes
Referrers
Orígenes
Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.

Result pages: 

(%s results)

Tags:

Tags: %s.

No tags

Slideshow:%s

Static Copy

Back to %s

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
alternativo
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
buscar
Wanted Pages

%s pages

%s, referenced from:

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION
